@@ -1,3 +1,3 @@
 """Scapy Manager package."""
 
-from .worker import Worker
+from .core.worker import Worker
